@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
-/* 
- * Copyright (C) 2011 Emweb bvba, Heverlee, Belgium
+/*
+ * Copyright (C) 2011 Emweb bv, Herent, Belgium
  *
  * See the LICENSE file for terms of use.
  */
@@ -8,14 +8,16 @@
 #ifndef WORD_WIDGET_H_
 #define WORD_WIDGET_H_
 
-#include <Wt/WContainerWidget>
+#include <Wt/WContainerWidget.h>
 
-class WordWidget : public Wt::WContainerWidget
+using namespace Wt;
+
+class WordWidget : public WContainerWidget
 {
 public:
-  WordWidget(Wt::WContainerWidget *parent = 0);
+  WordWidget();
 
-  std::wstring word() const { return word_; } 
+  std::wstring word() const { return word_; }
 
   void init(const std::wstring &word);
   bool guess(wchar_t c);
@@ -23,7 +25,7 @@ public:
   bool won();
 
 private:
-  std::vector<Wt::WText *>       wordLetters_;
+  std::vector<WText *>           wordLetters_;
   std::wstring                   word_;
 
   unsigned                       displayedLetters_;
