@@ -4,10 +4,9 @@
 
 SAMPLE_BEGIN(InPlaceEdit)
 
-auto container = Wt::cpp14::make_unique<Wt::WContainerWidget>();
+auto container = std::make_unique<Wt::WContainerWidget>();
 
-Wt::WInPlaceEdit *ipe =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WInPlaceEdit>("This is editable text"));
+Wt::WInPlaceEdit *ipe = container->addNew<Wt::WInPlaceEdit>("This is editable text");
 ipe->setPlaceholderText("Enter something");
 ipe->setButtonsEnabled(false);
 
